# civic_scraper.platforms.civic_plus

## Submodules

### civic_scraper.platforms.civic_plus.parser

```{eval-rst}
.. automodule:: civic_scraper.platforms.civic_plus.parser
   :members:
   :undoc-members:
   :show-inheritance:
```

### civic_scraper.platforms.civic_plus.site

```{eval-rst}
.. automodule:: civic_scraper.platforms.civic_plus.site
   :members:
   :undoc-members:
   :show-inheritance:
```
